/**
 * Checks if two objects are equal.
 *
 * @param {Object} obj1 - The first object to compare.
 * @param {Object} obj2 - The second object to compare.
 * @return {boolean} Returns true if the objects are equal, and false otherwise.
 */
export function EqualObjects(obj1: { [key: string | number | symbol]: any }, obj2: { [key: string | number | symbol]: any }): boolean {
    let result: boolean = true;
    if (obj1 === obj2) {
        return true;
    }
    const keys1 = Object.keys(obj1);
    const keys2 = Object.keys(obj2);
    if (keys1.length !== keys2.length) {
        result = false;
    }

    for (const key of keys1) {
        if (!keys2.includes(key)) {
            result = false;
            break;
        } else if (typeof obj1[key] === "string" || typeof obj1[key] === "number") {
            if (obj1[key] !== obj2[key]) {
                result = false;
                break;
            }
        } else if (Array.isArray(obj1[key])) {
            if (obj1[key].length !== obj2[key].length) {
                result = false;
                break;
            }
            for (let index in obj1[key]) {
                if (!EqualObjects(obj1[key][index], obj2[key][index])) {
                    result = false;
                    break;
                }
            }
            if (!result) break;
        } else if (typeof obj1[key] === "object") {
            if (!EqualObjects(obj1[key], obj2[key])) {
                result = false;
                break;
            }
        }
    }

    return result;
}
