/**
 * Checks if the given input is a valid number and optionally, if it falls within a specific range.
 *
 * @param {string | number} input - The value to check.
 * @param {number} [minInput] - The minimum acceptable value for the input.
 * @param {number} [maxInput] - The maximum acceptable value for the input.
 * @returns {boolean} - Returns `true` if the input is a valid number and falls within the specified range. Otherwise, it returns `false`.
 */
export function ValidNumber(input: string | number, minInput: number = Number.MIN_SAFE_INTEGER, maxInput: number = Number.MAX_SAFE_INTEGER): boolean {
    let num;
    if (typeof input === "string") {
        if (input === "") return false;
        num = Number(input);
        if (isNaN(num)) return false;
    } else {
        num = input;
    }
    return !(num < minInput || num > maxInput);
}
