/**
 * Concatenates the specified fields of an object using the passed separator or a space and places the result in the specified field, returning the full object
 *
 * @param {T} data - T.
 * @param {(keyof T)[]} [fieldsToConcat] - Which fields of the object to concatenate together
 * @param {string} [resultField] - The field to store the result in
 * @param {string} [separator] - The text to separate each field's value by. Default value for separator is " "
 * @returns {T} - Returns a new Object matching T with concatenated fields from , provided by what is stored in resultField
 */
export function ConcatenateKeys<T, K extends keyof T>(data: T, fieldsToConcat: K[] = [], resultField: K = "result" as K, separator: string = " "): T {
    if (typeof data === "object") {
        let newData: T = data;
        let textValue = "";
        fieldsToConcat.forEach((field, index) => {
            if (index > 0) textValue += separator + String(newData?.[field]);
            else textValue += String(newData?.[field]);
        });
        newData[resultField] = textValue as unknown as T[K];
        return newData;
    }
    return data;
}
